@@ -173,25 +173,26 @@ ClientStateStartServerListDownload::~ClientStateStartServerListDownload()
 void
 ClientStateStartServerListDownload::Enter(boost::shared_ptr<ClientThread> client)
 {
-	const ClientContext &context = client->GetContext();
-	path tmpServerListPath(context.GetCacheDir());
-	string serverListUrl(context.GetServerListUrl());
-	// Retrieve the file name from the URL.
-	size_t pos = serverListUrl.find_last_of('/');
-	if (context.GetCacheDir().empty() || serverListUrl.empty() || pos == string::npos || ++pos >= serverListUrl.length()) {
-		throw ClientException(__FILE__, __LINE__, ERR_SOCK_INVALID_SERVERLIST_URL, 0);
-	}
-	tmpServerListPath /= serverListUrl.substr(pos);
+	path tmpServerListPath(client->GetCacheServerListFileName());
 	if (exists(tmpServerListPath)) {
-		// Always download the current server list.
-		// If a previous file exists, delete it.
-		remove(tmpServerListPath);
+		// Download the current server list once a day.
+		// If the previous file is older than one day, delete it.
+		// Also delete the file if it is empty.
+		if (file_size(tmpServerListPath) == 0 || (last_write_time(tmpServerListPath) + 86400 < time(NULL))) {
+			remove(tmpServerListPath);
+		}
+	}
+
+	if (exists(tmpServerListPath)) {
+		// Use the existing server list.
+		client->SetState(ClientStateReadingServerList::Instance());
+	} else {
+		// Download the server list.
+		boost::shared_ptr<DownloadHelper> downloader(new DownloadHelper);
+		downloader->Init(client->GetContext().GetServerListUrl(), tmpServerListPath.directory_string());
+		ClientStateDownloadingServerList::Instance().SetDownloadHelper(downloader);
+		client->SetState(ClientStateDownloadingServerList::Instance());
 	}
-	// Download server list.
-	boost::shared_ptr<DownloadHelper> downloader(new DownloadHelper);
-	downloader->Init(serverListUrl, tmpServerListPath.directory_string());
-	ClientStateDownloadingServerList::Instance().SetDownloadHelper(downloader);
-	client->SetState(ClientStateDownloadingServerList::Instance());
 }
 
 void
@@ -493,8 +494,9 @@ ClientStateStartConnect::HandleConnect(const boost::system::error_code& ec, boos
 							++m_remoteEndpointIterator,
 							client));
 		} else {
-			if (ec != boost::asio::error::operation_aborted)
+			if (ec != boost::asio::error::operation_aborted) {
 				throw ClientException(__FILE__, __LINE__, ERR_SOCK_CONNECT_FAILED, ec.value());
+			}
 		}
 	}
 }
